@@ -108,7 +108,7 @@ class train_k_fold_pred():
 		
 					
 		test_ids_ds = self.test_ds.map(lambda image, idnum : idnum).unbatch()
-		test_ids = next(iter(test_ids_ds.batch(self.NUM_TEST_IMAGES))).numpy()
+		test_ids = next(iter(test_ids_ds.batch(self.NUM_TEST_IMAGES))).numpy().astype('U')
 		print("Generating predictions output file as predictions.csv")
 		
 		
